Returns an existing session if one with the given name is alive, otherwise
starts a new one. If db is supplied and an existing live session is
connected to a different database, an error is raised.
Value
A processx::process object (invisibly).
Examples
s1 = duckknit_get_session("demo")
s2 = duckknit_get_session("demo")
identical(s1$get_pid(), s2$get_pid())
#> [1] TRUE
duckknit_kill_session("demo")